<?php

declare(strict_types=1);

namespace Drupal\field_data\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\RedundantEditableConfigNamesTrait;

/**
 * Configure Local Tasks More settings for this site.
 */
final class FieldDataSettingsForm extends ConfigFormBase {
  use RedundantEditableConfigNamesTrait;

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'field_data_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $form['published'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display only published field data'),
      '#description' => $this->t('If checked, only published field data will be displayed.'),
      '#config_target' => 'field_data.settings:published',
    ];
    $form['default_langcode'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display only field data in the default language'),
      '#description' => $this->t('If checked, only field data in the default language will be displayed. If unchecked, all field data translations will be displayed.'),
      '#config_target' => 'field_data.settings:default_langcode',
    ];
    return parent::buildForm($form, $form_state);
  }

}
